##  Overview
You can upload your AI agents to SAP LeanIX through the AI Agent API without relying on integrations with agent-building systems. This REST API provides access to an endpoint for ingesting AI agent cards based on the Agent-to-Agent (A2A) protocol.
You upload AI agents as agent cards. An agent card is a digital credential or metadata construct that describes an AI agent's identity, capabilities, and endpoints for standardized discovery and interoperability between agents.
Your uploaded AI agents appear in the AI agent discovery inbox. You can review the discovered items and link them to existing fact sheets, or you can create and link new fact sheets.
